@@ -26,6 +26,7 @@
 #include "settings/wiredconnectionwidget.h"
 #include "settings/wiredsecurity.h"
 #include "settings/wireguardinterfacewidget.h"
+#include "uiutils.h"
 #include "vpnuiplugin.h"
 
 #include <NetworkManagerQt/ActiveConnection>
@@ -188,12 +189,13 @@ void ConnectionEditorBase::initialize()
     const NetworkManager::ConnectionSettings::ConnectionType type = m_connection->connectionType();
 
     if (emptyConnection) {
-        m_connection->addToPermissions(KUser().loginName(), QString());
+        UiUtils::setConnectionDefaultPermissions(m_connection);
     }
 
     // General configuration common to all connection types
     auto connectionWidget = new ConnectionWidget(m_connection);
     addConnectionWidget(connectionWidget, i18nc("General", "General configuration"));
+    connect(connectionWidget, &ConnectionWidget::allUsersChanged, this, &ConnectionEditorBase::onAllUsersChanged);
 
     // Add the rest of widgets
     QString serviceType;
@@ -211,6 +213,7 @@ void ConnectionEditorBase::initialize()
                                              this);
         addSettingWidget(wifiSecurity, i18n("Wi-Fi Security"));
         connect(wifiWidget, QOverload<const QString &>::of(&WifiConnectionWidget::ssidChanged), wifiSecurity, &WifiSecurity::onSsidChanged);
+        m_wifiSecurity = wifiSecurity;
     } else if (type == NetworkManager::ConnectionSettings::Pppoe) { // DSL
         auto pppoeWidget = new PppoeWidget(m_connection->setting(NetworkManager::Setting::Pppoe), this);
         addSettingWidget(pppoeWidget, i18n("DSL"));
@@ -513,3 +516,13 @@ void ConnectionEditorBase::validChanged(bool valid)
     m_valid = true;
     Q_EMIT validityChanged(true);
 }
+
+void ConnectionEditorBase::onAllUsersChanged()
+{
+    if (!m_wifiSecurity) {
+        return;
+    }
+
+    auto allUsers = m_connectionWidget->allUsers();
+    m_wifiSecurity->setStoreSecretsSystemWide(allUsers);
+}
