@@ -1,22 +1,8 @@
 /*
-    Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
-    Copyright 2015 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013 Lukas Tinkl <ltinkl@redhat.com>
+    SPDX-FileCopyrightText: 2015 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "cdmawidget.h"
@@ -121,8 +107,8 @@ bool CdmaWidget::isValid() const
 {
     bool passwordUserValid = true;
 
-    if (m_ui->password->passwordOption() == PasswordField::StoreForUser ||
-        m_ui->password->passwordOption() == PasswordField::StoreForAllUsers) {
+    if (m_ui->password->passwordOption() == PasswordField::StoreForUser //
+        || m_ui->password->passwordOption() == PasswordField::StoreForAllUsers) {
         passwordUserValid = !m_ui->username->text().isEmpty() && !m_ui->password->text().isEmpty();
     } else if (m_ui->password->passwordOption() == PasswordField::AlwaysAsk) {
         passwordUserValid = !m_ui->username->text().isEmpty();
