@@ -12,6 +12,7 @@
 
 #include <NetworkManagerQt/Security8021xSetting>
 
+#include "passwordfield.h"
 #include "settingwidget.h"
 
 namespace Ui
@@ -36,6 +37,8 @@ public:
 
     bool isValid() const override;
 
+    void setPasswordOption(PasswordField::PasswordOption option);
+
 private Q_SLOTS:
     void altSubjectMatchesButtonClicked();
     void connectToServersButtonClicked();
