@@ -9,6 +9,8 @@
 #include "networkmodelitem.h"
 #include "plasma_nm_libs.h"
 #include "uiutils.h"
+#include <QVector>
+#include <algorithm>
 
 #if WITH_MODEMMANAGER_SUPPORT
 #include <ModemManagerQt/Manager>
@@ -93,6 +95,8 @@ QVariant NetworkModel::data(const QModelIndex &index, int role) const
             return item->rxBytes();
         case TxBytesRole:
             return item->txBytes();
+        case DelayModelUpdatesRole:
+            return item->delayModelUpdates();
         default:
             break;
         }
@@ -101,6 +105,23 @@ QVariant NetworkModel::data(const QModelIndex &index, int role) const
     return {};
 }
 
+bool NetworkModel::setData(const QModelIndex &index, const QVariant &value, int role)
+{
+    const int row = index.row();
+    const bool delay = value.toBool();
+
+    if (row >= 0 && row < m_list.count() && role == DelayModelUpdatesRole) {
+        NetworkModelItem *item = m_list.itemAt(row);
+        if (item->delayModelUpdates() != delay) {
+            item->setDelayModelUpdates(delay);
+            dataChanged(index, index, QVector<int>{DelayModelUpdatesRole});
+            updateDelayModelUpdates();
+            return true;
+        }
+    }
+    return false;
+}
+
 int NetworkModel::rowCount(const QModelIndex &parent) const
 {
     Q_UNUSED(parent);
@@ -138,25 +159,42 @@ QHash<int, QByteArray> NetworkModel::roleNames() const
     roles[VpnType] = "VpnType";
     roles[RxBytesRole] = "RxBytes";
     roles[TxBytesRole] = "TxBytes";
+    roles[DelayModelUpdatesRole] = "DelayModelUpdates";
 
     return roles;
 }
 
-void NetworkModel::setDelayModelUpdates(bool delayUpdates)
+bool NetworkModel::delayModelUpdates() const
 {
-    m_delayModelUpdates = delayUpdates;
+    return m_delayModelUpdates;
+}
 
-    // Process queue
-    if (!delayUpdates) {
-        while (!m_updateQueue.isEmpty()) {
-            QPair<NetworkModel::ModelChangeType, NetworkModelItem *> update = m_updateQueue.dequeue();
-            if (update.first == ItemAdded) {
-                insertItem(update.second);
-            } else if (update.first == ItemRemoved) {
-                removeItem(update.second);
-            } else if (update.first == ItemPropertyChanged) {
-                updateItem(update.second);
-            }
+void NetworkModel::updateDelayModelUpdates()
+{
+    const QList<NetworkModelItem *> items = m_list.items();
+    const bool delay = std::any_of(items.begin(), items.end(), [](NetworkModelItem *item) -> bool {
+        return item->delayModelUpdates();
+    });
+    if (m_delayModelUpdates != delay) {
+        m_delayModelUpdates = delay;
+        Q_EMIT delayModelUpdatesChanged();
+
+        if (!m_delayModelUpdates) {
+            flushUpdateQueue();
+        }
+    }
+}
+
+void NetworkModel::flushUpdateQueue()
+{
+    while (!m_updateQueue.isEmpty()) {
+        QPair<NetworkModel::ModelChangeType, NetworkModelItem *> update = m_updateQueue.dequeue();
+        if (update.first == ItemAdded) {
+            insertItem(update.second);
+        } else if (update.first == ItemRemoved) {
+            removeItem(update.second);
+        } else if (update.first == ItemPropertyChanged) {
+            updateItem(update.second);
         }
     }
 }
@@ -330,7 +368,7 @@ void NetworkModel::addActiveConnection(const NetworkManager::ActiveConnection::P
                 item->setVpnState(state);
             }
             item->invalidateDetails();
-            qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": active connection state changed to " << item->connectionState();
+            qCDebug(PLASMA_NM_LIBS_LOG).nospace() << "Item " << item->name() << ": active connection state changed to " << item->connectionState();
 
             if (device && device->uni() == item->devicePath()) {
                 auto deviceStatistics = device->deviceStatistics();
@@ -364,7 +402,7 @@ void NetworkModel::addAvailableConnection(const QString &connection, const Netwo
 
         item->setDevicePath(device->uni());
         item->setDeviceState(device->state());
-        qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": device changed to " << item->devicePath();
+        qCDebug(PLASMA_NM_LIBS_LOG).nospace() << "Item " << item->name() << ": device changed to " << item->devicePath();
 #if WITH_MODEMMANAGER_SUPPORT
         if (device->type() == NetworkManager::Device::Modem) {
             ModemManager::ModemDevice::Ptr modemDevice = ModemManager::findModemDevice(device->udi());
@@ -372,7 +410,7 @@ void NetworkModel::addAvailableConnection(const QString &connection, const Netwo
                 ModemManager::Modem::Ptr modemInterface = modemDevice->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
                 if (modemInterface) {
                     item->setSignal(modemInterface->signalQuality().signal);
-                    qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": signal changed to " << item->signal();
+                    qCDebug(PLASMA_NM_LIBS_LOG).nospace() << "Item " << item->name() << ": signal changed to " << item->signal();
                 }
             }
         }
@@ -382,7 +420,7 @@ void NetworkModel::addAvailableConnection(const QString &connection, const Netwo
             for (NetworkModelItem *secondItem : m_list.returnItems(NetworkItemsList::Ssid, item->ssid())) {
                 if (secondItem->itemType() == NetworkModelItem::AvailableAccessPoint && secondItem->devicePath() == item->devicePath()) {
                     removeItem(secondItem);
-                    qCDebug(PLASMA_NM_LIBS_LOG) << "Access point " << secondItem->name() << ": merged to " << item->name() << " connection";
+                    qCDebug(PLASMA_NM_LIBS_LOG).nospace() << "Access point " << secondItem->name() << ": merged to " << item->name() << " connection";
                     break;
                 }
             }
@@ -444,7 +482,7 @@ void NetworkModel::addConnection(const NetworkManager::Connection::Ptr &connecti
     item->invalidateDetails();
 
     insertItem(item);
-    qCDebug(PLASMA_NM_LIBS_LOG) << "New connection " << item->name() << " added";
+    qCDebug(PLASMA_NM_LIBS_LOG) << "New connection" << item->name() << "added";
 }
 
 void NetworkModel::addDevice(const NetworkManager::Device::Ptr &device)
@@ -540,7 +578,7 @@ void NetworkModel::addWirelessNetwork(const NetworkManager::WirelessNetwork::Ptr
     item->invalidateDetails();
 
     insertItem(item);
-    qCDebug(PLASMA_NM_LIBS_LOG) << "New wireless network " << item->name() << " added";
+    qCDebug(PLASMA_NM_LIBS_LOG) << "New wireless network" << item->name() << "added";
 }
 
 void NetworkModel::checkAndCreateDuplicate(const QString &connection, const QString &deviceUni)
@@ -595,6 +633,7 @@ void NetworkModel::insertItem(NetworkModelItem *item)
     beginInsertRows(QModelIndex(), index, index);
     m_list.insertItem(item);
     endInsertRows();
+    updateDelayModelUpdates();
 }
 
 void NetworkModel::removeItem(NetworkModelItem *item)
@@ -605,30 +644,29 @@ void NetworkModel::removeItem(NetworkModelItem *item)
     }
 
     const int row = m_list.indexOf(item);
-    if (row >= 0) {
+    if (row != -1) {
         beginRemoveRows(QModelIndex(), row, row);
         m_list.removeItem(item);
         item->deleteLater();
         endRemoveRows();
+        updateDelayModelUpdates();
     }
 }
 
 void NetworkModel::updateItem(NetworkModelItem *item)
 {
-    const QVector<int> changedRoles = item->changedRoles();
-    // Check only primary roles which can change item order
-    if (m_delayModelUpdates && (changedRoles.contains(ConnectionStateRole) || changedRoles.contains(ItemTypeRole) || changedRoles.contains(SignalRole))) {
+    if (m_delayModelUpdates) {
         m_updateQueue.enqueue(QPair<NetworkModel::ModelChangeType, NetworkModelItem *>(NetworkModel::ItemPropertyChanged, item));
         return;
     }
 
     const int row = m_list.indexOf(item);
-
-    if (row >= 0) {
+    if (row != -1) {
         item->invalidateDetails();
         QModelIndex index = createIndex(row, 0);
         Q_EMIT dataChanged(index, index, item->changedRoles());
         item->clearChangedRoles();
+        updateDelayModelUpdates();
     }
 }
 
@@ -643,7 +681,7 @@ void NetworkModel::accessPointSignalStrengthChanged(int signal)
         if (item->specificPath() == apPtr->uni()) {
             item->setSignal(signal);
             updateItem(item);
-            qCDebug(PLASMA_NM_LIBS_LOG) << "AccessPoint " << item->name() << ": signal changed to " << item->signal();
+            qCDebug(PLASMA_NM_LIBS_LOG).nospace() << "AccessPoint " << item->name() << ": signal changed to " << item->signal();
         }
     }
 }
@@ -664,7 +702,7 @@ void NetworkModel::activeConnectionRemoved(const QString &activeConnection)
         item->setConnectionState(NetworkManager::ActiveConnection::Deactivated);
         item->setVpnState(NetworkManager::VpnConnection::Disconnected);
         updateItem(item);
-        qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": active connection removed";
+        qCDebug(PLASMA_NM_LIBS_LOG).nospace() << "Item " << item->name() << ": active connection removed";
     }
 }
 
@@ -705,7 +743,7 @@ void NetworkModel::activeVpnConnectionStateChanged(NetworkManager::VpnConnection
         }
         item->setVpnState(state);
         updateItem(item);
-        qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": active connection changed to " << item->connectionState();
+        qCDebug(PLASMA_NM_LIBS_LOG).nospace() << "Item " << item->name() << ": active connection changed to " << item->connectionState();
     }
 }
 
@@ -747,7 +785,7 @@ void NetworkModel::availableConnectionDisappeared(const QString &connection)
             item->setDeviceState(NetworkManager::Device::UnknownState);
             item->setSignal(0);
             item->setSpecificPath(QString());
-            qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << " removed as available connection";
+            qCDebug(PLASMA_NM_LIBS_LOG) << "Item" << item->name() << "removed as available connection";
             // Check whether the connection is still available as an access point, this happens
             // when we change its properties, like ssid, bssid, security etc.
             if (item->type() == NetworkManager::ConnectionSettings::Wireless && !specificPath.isEmpty()) {
@@ -767,7 +805,7 @@ void NetworkModel::availableConnectionDisappeared(const QString &connection)
 
             if (item->duplicate()) {
                 removeItem(item);
-                qCDebug(PLASMA_NM_LIBS_LOG) << "Duplicate item " << item->name() << " removed completely";
+                qCDebug(PLASMA_NM_LIBS_LOG) << "Duplicate item" << item->name() << "removed completely";
             } else {
                 updateItem(item);
             }
@@ -811,7 +849,7 @@ void NetworkModel::connectionRemoved(const QString &connection)
                 item->setTimestamp(QDateTime());
                 item->setUuid(QString());
                 updateItem(item);
-                qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": connection removed";
+                qCDebug(PLASMA_NM_LIBS_LOG).nospace() << "Item " << item->name() << ": connection removed";
             }
         } else {
             remove = true;
@@ -819,7 +857,7 @@ void NetworkModel::connectionRemoved(const QString &connection)
 
         if (remove) {
             removeItem(item);
-            qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << " removed completely";
+            qCDebug(PLASMA_NM_LIBS_LOG) << "Item" << item->name() << "removed completely";
         }
         remove = false;
     }
@@ -850,7 +888,7 @@ void NetworkModel::connectionUpdated()
         }
 
         updateItem(item);
-        qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": connection updated";
+        qCDebug(PLASMA_NM_LIBS_LOG).nospace() << "Item " << item->name() << ": connection updated";
     }
 }
 
@@ -1024,7 +1062,7 @@ void NetworkModel::statusChanged(NetworkManager::Status status)
 {
     Q_UNUSED(status);
 
-    qCDebug(PLASMA_NM_LIBS_LOG) << "NetworkManager state changed to " << status;
+    qCDebug(PLASMA_NM_LIBS_LOG) << "NetworkManager state changed to" << status;
     // This has probably effect only for VPN connections
     for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Type, NetworkManager::ConnectionSettings::Vpn)) {
         updateItem(item);
@@ -1052,7 +1090,7 @@ void NetworkModel::wirelessNetworkDisappeared(const QString &ssid)
         // Remove the entire item, because it's only AP or it's a duplicated available connection
         if (item->itemType() == NetworkModelItem::AvailableAccessPoint || item->duplicate()) {
             removeItem(item);
-            qCDebug(PLASMA_NM_LIBS_LOG) << "Wireless network " << item->name() << " removed completely";
+            qCDebug(PLASMA_NM_LIBS_LOG) << "Wireless network" << item->name() << "removed completely";
             // Remove only AP and device from the item and leave it as an unavailable connection
         } else {
             if (item->mode() == NetworkManager::WirelessSetting::Infrastructure) {
@@ -1062,7 +1100,7 @@ void NetworkModel::wirelessNetworkDisappeared(const QString &ssid)
             }
             item->setSignal(0);
             updateItem(item);
-            qCDebug(PLASMA_NM_LIBS_LOG) << "Item " << item->name() << ": wireless network removed";
+            qCDebug(PLASMA_NM_LIBS_LOG).nospace() << "Item " << item->name() << ": wireless network removed";
         }
     }
 }
